@@ -15,7 +15,7 @@ import xmltodict
 import pysftp
 
 # Self import
-# from apps.third_party.django_logging.decorators import logger
+from logstack.decorators import log_to_remote
 from .models import LabportalenReport
 
 
@@ -88,7 +88,7 @@ class BaseLabportalenService(metaclass=abc.ABCMeta):
 
 
 
-class LabportalenServices(BaseLabportalenService):
+class LabportalenService(BaseLabportalenService):
 
     def __init__(self) -> None:
         super().__init__()
@@ -116,6 +116,7 @@ class LabportalenServices(BaseLabportalenService):
             raise Exception(f"Can not connect to the SFTP server, Exception: {e}")
         return sftp
     
+    @log_to_remote(settings.HTTP_LOGGER)
     def fetch_reports(self, requisition_id: Optional[str]=None) -> None:
         '''
         Fetches report from SFTP server
@@ -177,6 +178,7 @@ class LabportalenServices(BaseLabportalenService):
         for report in reports:
             report_summary = {
                 'analysis_name': report.get('@AnaName'),
+                'analysis_code': report.get('@TestMethodCode'),
                 'analysis_result': report.get('@Value'),
                 'unit': report.get('@Unit'),
                 'ref_text': report.get('@RefText'),
